package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

type IvrStateEnum int32

const (
	IvrStateWelcome                  IvrStateEnum = 0
	IvrStateWelcomeResponse          IvrStateEnum = 1
	IvrStateEnterPropertyRef         IvrStateEnum = 2
	IvrStateEnterPropertyRefResponse IvrStateEnum = 3
	IvrStateEnterPropertyRefRepeat   IvrStateEnum = 4
	IvrStatePropertyRefIncorrect     IvrStateEnum = 5
	IvrStatePropertyRef              IvrStateEnum = 6
	IvrStateMobileCorrect            IvrStateEnum = 7
	IvrStateMobile                   IvrStateEnum = 8
	IvrStateSmsResponse              IvrStateEnum = 9
	IvrStateBookAgain                IvrStateEnum = 10
	IvrStateMorePropertyInfo         IvrStateEnum = 11
	IvrStateTalkToSupport            IvrStateEnum = 12
	IvrStateHowToList                IvrStateEnum = 13
	IvrStateAnotherQuery             IvrStateEnum = 14
	IvrStateOutro                    IvrStateEnum = 15
	IvrStateOutroOutOfHours          IvrStateEnum = 16
)

type IVRState struct {
	ID          primitive.ObjectID `bson:"_id,omitempty"`
	CallSid     string             `bson:"call_sid,omitempty"`
	State       IvrStateEnum       `bson:"state,omitempty"`
	PropertyIDs []string           `bson:"property,omitempty"`
	Created     time.Time          `bson:"created,omitempty"`
	Updated     time.Time          `bson:"updated,omitempty"`
	Delete      bool               `bson:"-"`
}

func (m *IVRState) Changed(old *IVRState) bool {
	if old.CallSid != m.CallSid || old.State != m.State {
		return true
	}

	if len(old.PropertyIDs) != len(m.PropertyIDs) {
		return true
	}

	for i, v := range old.PropertyIDs {
		if m.PropertyIDs[i] != v {
			return true
		}
	}

	return false
}
