package mongo

import (
	"context"
	"errors"
	"time"

	"gitlab.mashplace.com/mashroom/backend/twilio/internal/model"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/bson/primitive"
	"go.mongodb.org/mongo-driver/mongo"
	"go.mongodb.org/mongo-driver/mongo/options"
)

type repositoryImplTwilio struct {
	Twilio *mongo.Collection
}

func (repo *repositoryImplTwilio) IVRStateSave(ctx context.Context, state *model.IVRState) error {
	if state.ID.IsZero() {
		state.ID = primitive.NewObjectID()
		state.Created = time.Now()
	}

	state.Updated = time.Now()

	_, err := repo.Twilio.ReplaceOne(ctx, bson.M{"_id": state.ID}, state, options.Replace().SetUpsert(true))

	return err
}

func (repo *repositoryImplTwilio) IVRStateRemoveBySID(ctx context.Context, sid string) error {
	_, err := repo.Twilio.DeleteMany(ctx, bson.M{"call_sid": sid})

	return err
}

func (repo *repositoryImplTwilio) IVRStateGetBySID(ctx context.Context, sid string) (*model.IVRState, error) {
	var m model.IVRState

	err := repo.Twilio.FindOne(ctx, bson.M{"call_sid": sid}).Decode(&m)
	if errors.Is(err, mongo.ErrNoDocuments) {
		return nil, nil
	}

	if err != nil {
		return nil, err
	}

	return &m, nil
}
